@@ -13,7 +13,7 @@ from .errors import KineticlibError
 from math import exp
 
 
-def Gamma_VT(T: float, T1: float, molecule: MoleculeMultiT, delta: int=-1) -> float:
+def Gamma_VT(T: float, T1: float, molecule: MoleculeMultiT, delta: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VT}` for a VT transition:
     **M(i) + P -> M(i+delta) + P** in the multi-temperature approximation
 
@@ -217,7 +217,7 @@ def find_natom_diss_eq(T: float, molecule: MoleculeOneT, atom: Atom, n: float, r
     return raw_find_natom_diss_eq(T, molecule.Z_int(T), molecule.mass, atom.mass, molecule.diss, n, relative)
 
 
-def raw_Gamma_VT(T: float, T1: float, vibr_one: float, delta: int=-1) -> float:
+def raw_Gamma_VT(T: float, T1: float, vibr_one: float, delta: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VT}` for a VT transition:
     **M(i) + P -> M(i+delta) + P** in the multi-temperature approximation, *raw* version
 
