@@ -30,13 +30,14 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
         the array of interaction data
     model : str
         the interaction model to be used, possible values:
-            * 'IPL' (Inverse Power Law potential)
+            * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
+            * 'BM' (Born-Mayer potential)
             * 'LJ' (Lennard-Jones potential)
+            * 'MLJ' (Modified Lennard-Jones model)
             * 'RS' (Rigid Sphere model)
             * 'VSS' (Variable Soft Sphere model)
             * 'Switch' (returns the result for the Lennard-Jones model when :math:`T / \\varepsilon_{cd} < 10`
               and for the IPL potential otherwise)
-            * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
 
         defaults to 'ESA'
     dimensional : bool
@@ -68,7 +69,7 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
             return omega_dimensionless_esa(T, l, r, idata[13], idata[14])
     elif model == 'Switch' and l == r:
         if T / idata[2] > 10:
-            om_dimless = omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])
+            om_dimless = omega_dimensionless_BM(T, l, idata[1], idata[2], idata[3], idata[4])
         else:
             om_dimless = omega_dimensionless_LJ(T, l, idata[2])
         if dimensional:
@@ -80,12 +81,17 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
             return omega_dimensionless_LJ(T, l, idata[2]) * omega_rigid_sphere(T, l, l, idata[1], idata[0], nokt)
         else:
             return omega_dimensionless_LJ(T, l, idata[2])
+    elif model == 'MLJ' and l == r:
+        if dimensional:
+            return omega_dimensionless_MLJ(T, l, idata[2]) * omega_rigid_sphere(T, l, l, idata[1], idata[0], nokt)
+        else:
+            return omega_dimensionless_MLJ(T, l, idata[2])
     elif model == 'IPL' and l == r:
         if dimensional:
-            return omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])\
+            return omega_dimensionless_BM(T, l, idata[1], idata[2], idata[3], idata[4])\
                    * omega_rigid_sphere(T, l, r, idata[1], idata[0], nokt)
         else:
-            return omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])
+            return omega_dimensionless_BM(T, l, idata[1], idata[2], idata[3], idata[4])
     elif model == 'VSS' and l == r:
         if dimensional:
             return omega_vss(T, l, idata[0], idata[5 + 2 * (l - 1)], idata[6 + 2 * (l - 1)], nokt)
@@ -169,8 +175,34 @@ def omega_dimensionless_LJ(T: float, l: int, eps: float) -> float:
                 + f[4] * (tmp ** 2) + f[5] * (tmp ** 3))
 
 
-def omega_dimensionless_IPL(T: float, l: int, sigma: float, eps: float, phizero: float, beta: float) -> float:
-    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the IPL potential (for ``l=1`` and ``l=2``)
+def omega_dimensionless_MLJ(T: float, l: int, eps: float) -> float:
+    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral using the modified Lennard-Jones model (for
+    ``l=1`` and ``l=2``)
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    l : int
+        the `l` degree of the integral
+    eps : float
+        the Lennard-Jones :math:`\\varepsilon_{cd}` parameter, divided by Boltzmann's constant
+
+    Returns
+    -------
+    float
+        The dimensionless calculated modified Lennard-Jones omega integral
+
+    Raises
+    ------
+    KineticlibError
+        if ``l`` not in `{1,2}`
+    """
+    return 0.9 * omega_dimensionless_LJ(T, l, eps) * ((T / 2000.) ** (-0.25))
+
+
+def omega_dimensionless_BM(T: float, l: int, sigma: float, eps: float, phizero: float, beta: float) -> float:
+    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the Born-Mayer potential (for ``l=1`` and ``l=2``)
 
     Parameters
     ----------
